@@ -1,17 +1,19 @@
 """Cross-python stdlib shims."""
 
 import os
-import typing as t
+import sys
+from collections.abc import Iterator
 from contextlib import contextmanager
 from pathlib import Path
 
-# isort: off
-try:
-    from contextlib import chdir as chdir_cm  # type: ignore[attr-defined, unused-ignore] # noqa: E501
-except ImportError:
+if sys.version_info >= (3, 11):
+    from contextlib import chdir as chdir_cm
+    from tomllib import loads as load_toml_from_string
+else:
+    from tomli import loads as load_toml_from_string
 
-    @contextmanager  # type: ignore[no-redef, unused-ignore]
-    def chdir_cm(path: os.PathLike) -> t.Iterator[None]:
+    @contextmanager  # type: ignore[no-redef]
+    def chdir_cm(path: "os.PathLike[str]") -> Iterator[None]:
         """Temporarily change the current directory, recovering on exit."""
         original_wd = Path.cwd()
         os.chdir(path)
@@ -21,13 +23,4 @@ except ImportError:
             os.chdir(original_wd)
 
 
-# isort: on
-
-
-try:
-    from tomllib import loads as load_toml_from_string
-except ImportError:
-    from tomli import loads as load_toml_from_string
-
-
 __all__ = ("chdir_cm", "load_toml_from_string")  # noqa: WPS410
